@@ -1,10 +1,9 @@
 from .openmeteo import get_wave_forecast, get_wind_forecast
-from .openstreetmap import driving_hours_to_meters, get_area_lat_lon, get_surfing_spots
+from .openstreetmap import driving_hours_to_meters, get_area_lat_lon
 
 __all__ = [
     "driving_hours_to_meters",
     "get_area_lat_lon",
-    "get_surfing_spots",
     "get_wave_forecast",
     "get_wind_forecast",
 ]
