@@ -3,7 +3,7 @@ from __future__ import annotations
 import asyncio
 import builtins
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Any, assert_never, overload
+from typing import TYPE_CHECKING, Any, Self, assert_never, overload
 
 from any_llm.utils.aio import run_async_in_sync
 from opentelemetry import trace as otel_trace
@@ -19,9 +19,10 @@ from any_agent.config import (
 )
 from any_agent.tools.wrappers import _wrap_tools
 from any_agent.tracing.agent_trace import AgentTrace
-from any_agent.tracing.attributes import GenAI
+from any_agent.tracing.attributes import AnyAgentAttributes, GenAI
 
 if TYPE_CHECKING:
+    import types
     from collections.abc import Sequence
 
     from opentelemetry.trace import Tracer
@@ -155,10 +156,32 @@ class AnyAgent(ABC):
 
     async def _load_tools(self, tools: Sequence[Tool]) -> list[Any]:
         tools, mcp_clients = await _wrap_tools(tools, self.framework)
-        # Add to agent so that it doesn't get garbage collected
         self._mcp_clients.extend(mcp_clients)
         return tools
 
+    async def cleanup_async(self) -> None:
+        """Clean up resources including MCP client connections.
+
+        This should be called when you're done using the agent to ensure
+        all resources are properly released.
+        """
+        for client in self._mcp_clients:
+            await client.disconnect()
+        self._mcp_clients.clear()
+
+    async def __aenter__(self) -> Self:
+        """Enter the async context manager."""
+        return self
+
+    async def __aexit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_val: BaseException | None,
+        exc_tb: types.TracebackType | None,
+    ) -> None:
+        """Exit the async context manager and clean up resources."""
+        await self.cleanup_async()
+
     def run(self, prompt: str, **kwargs: Any) -> AgentTrace:
         """Run the agent with the given prompt."""
         return run_async_in_sync(
@@ -203,6 +226,9 @@ class AnyAgent(ABC):
                             agent=self,  # type: ignore[arg-type]
                         )
 
+                # Importing here to avoid circular import issues
+                from any_agent import __version__ as _ANY_AGENT_VERSION  # noqa: N812
+
                 invoke_span.set_attributes(
                     {
                         GenAI.OPERATION_NAME: "invoke_agent",
@@ -210,6 +236,7 @@ class AnyAgent(ABC):
                         GenAI.AGENT_DESCRIPTION: self.config.description
                         or "No description.",
                         GenAI.REQUEST_MODEL: self.config.model_id,
+                        AnyAgentAttributes.VERSION: _ANY_AGENT_VERSION,
                     }
                 )
 
