@@ -83,13 +83,6 @@ def assert_duration(agent_trace: AgentTrace, wall_time_s: float) -> None:
     )
 
 
-def assert_cost(agent_trace: AgentTrace) -> None:
-    assert isinstance(agent_trace.cost, CostInfo)
-    assert agent_trace.cost.input_cost > 0
-    assert agent_trace.cost.output_cost > 0
-    assert agent_trace.cost.input_cost + agent_trace.cost.output_cost < 1.00
-
-
 def assert_tokens(agent_trace: AgentTrace) -> None:
     assert isinstance(agent_trace.tokens, TokenInfo)
     assert agent_trace.tokens.input_tokens > 0
@@ -111,11 +104,10 @@ class Steps(BaseModel):
     [
         # Disabling anthropic until output_type can be handled without relying on `response_format`
         # because that is not supported in some providers.
-        # "anthropic/claude-3-5-haiku-latest",
-        "gemini/gemini-2.5-flash",
-        "huggingface/tgi",  # This is a Qwen/Qwen3-1.7B hosted in https://endpoints.huggingface.co/mozilla-ai/endpoints/dedicated
-        "openai/gpt-4.1-nano",
-        "xai/grok-3-mini-latest",
+        # "anthropic:claude-3-5-haiku-latest",
+        "gemini:gemini-2.5-flash",
+        "openai:gpt-4.1-nano",
+        "xai:grok-3-mini-latest",
         DEFAULT_SMALL_MODEL_ID,
     ],
 )
@@ -149,7 +141,7 @@ def test_load_and_run_agent(
         with open(os.path.join(tmp_path, tmp_file), "w", encoding="utf-8") as f:
             f.write(text)
 
-    model_args = get_default_agent_model_args(agent_framework)
+    model_args = get_default_agent_model_args(agent_framework, model_id=model_id)
 
     if "gemini" in model_id:
         model_args.pop("parallel_tool_calls", None)
@@ -197,12 +189,12 @@ def test_load_and_run_agent(
 
     assert_trace(agent_trace, agent_framework)
     assert_duration(agent_trace, (end_ns - start_ns) / 1_000_000_000)
-    if model_id not in ("huggingface/tgi", "google/gemini-2.5-flash"):
-        assert_cost(agent_trace)
     assert_tokens(agent_trace)
 
     if update_trace:
-        trace_path = Path(__file__).parent.parent / "assets" / agent_framework.name
+        trace_path = (
+            Path(__file__).parent.parent.parent / "assets" / agent_framework.name
+        )
         with open(f"{trace_path}_trace.json", "w", encoding="utf-8") as f:
             f.write(agent_trace.model_dump_json(indent=2, serialize_as_any=True))
             f.write("\n")
