@@ -13,25 +13,25 @@ from any_agent.tools import (
 def test_load_openai_default() -> None:
     mock_agent = MagicMock()
     mock_function_tool = MagicMock()
-    mock_litellm_model = MagicMock()
+    mock_model = MagicMock()
 
     with (
         patch("any_agent.frameworks.openai.Agent", mock_agent),
         patch("agents.function_tool", mock_function_tool),
-        patch("any_agent.frameworks.openai.DEFAULT_MODEL_TYPE", mock_litellm_model),
+        patch("any_agent.frameworks.openai.DEFAULT_MODEL_TYPE", mock_model),
     ):
         AnyAgent.create(
-            AgentFramework.OPENAI, AgentConfig(model_id="mistral/mistral-small-latest")
+            AgentFramework.OPENAI, AgentConfig(model_id="mistral:mistral-small-latest")
         )
 
-        mock_litellm_model.assert_called_once_with(
-            model="mistral/mistral-small-latest",
+        mock_model.assert_called_once_with(
+            model="mistral:mistral-small-latest",
             base_url=None,
             api_key=None,
         )
         mock_agent.assert_called_once_with(
             name="any_agent",
-            model=mock_litellm_model.return_value,
+            model=mock_model.return_value,
             instructions=None,
             tools=[],
             mcp_servers=[],
@@ -40,22 +40,22 @@ def test_load_openai_default() -> None:
 
 def test_openai_with_api_base() -> None:
     mock_agent = MagicMock()
-    litllm_model_mock = MagicMock()
+    mock_model = MagicMock()
     with (
         patch("any_agent.frameworks.openai.Agent", mock_agent),
         patch(
             "any_agent.frameworks.openai.DEFAULT_MODEL_TYPE",
-            litllm_model_mock,
+            mock_model,
         ),
     ):
         AnyAgent.create(
             AgentFramework.OPENAI,
             AgentConfig(
-                model_id="mistral/mistral-small-latest", model_args={}, api_base="FOO"
+                model_id="mistral:mistral-small-latest", model_args={}, api_base="FOO"
             ),
         )
-        litllm_model_mock.assert_called_once_with(
-            model="mistral/mistral-small-latest",
+        mock_model.assert_called_once_with(
+            model="mistral:mistral-small-latest",
             base_url="FOO",
             api_key=None,
         )
@@ -63,22 +63,22 @@ def test_openai_with_api_base() -> None:
 
 def test_openai_with_api_key() -> None:
     mock_agent = MagicMock()
-    litellm_model_mock = MagicMock()
+    mock_model = MagicMock()
     with (
         patch("any_agent.frameworks.openai.Agent", mock_agent),
         patch(
             "any_agent.frameworks.openai.DEFAULT_MODEL_TYPE",
-            litellm_model_mock,
+            mock_model,
         ),
     ):
         AnyAgent.create(
             AgentFramework.OPENAI,
             AgentConfig(
-                model_id="mistral/mistral-small-latest", model_args={}, api_key="FOO"
+                model_id="mistral:mistral-small-latest", model_args={}, api_key="FOO"
             ),
         )
-        litellm_model_mock.assert_called_once_with(
-            model="mistral/mistral-small-latest",
+        mock_model.assert_called_once_with(
+            model="mistral:mistral-small-latest",
             base_url=None,
             api_key="FOO",
         )
@@ -87,13 +87,13 @@ def test_openai_with_api_key() -> None:
 def test_load_openai_with_mcp_server() -> None:
     mock_agent = MagicMock()
     mock_function_tool = MagicMock()
-    mock_litellm_model = MagicMock()
+    mock_model = MagicMock()
     mock_wrap_tools = MagicMock()
 
     with (
         patch("any_agent.frameworks.openai.Agent", mock_agent),
         patch("agents.function_tool", mock_function_tool),
-        patch("any_agent.frameworks.openai.DEFAULT_MODEL_TYPE", mock_litellm_model),
+        patch("any_agent.frameworks.openai.DEFAULT_MODEL_TYPE", mock_model),
         patch.object(AnyAgent, "_load_tools", mock_wrap_tools),
     ):
 
@@ -109,7 +109,7 @@ def test_load_openai_with_mcp_server() -> None:
         AnyAgent.create(
             AgentFramework.OPENAI,
             AgentConfig(
-                model_id="mistral/mistral-small-latest",
+                model_id="mistral:mistral-small-latest",
                 tools=[
                     MCPStdio(
                         command="docker",
@@ -124,7 +124,7 @@ def test_load_openai_with_mcp_server() -> None:
         # No separate MCP servers with new architecture
         mock_agent.assert_called_once_with(
             name="any_agent",
-            model=mock_litellm_model.return_value,
+            model=mock_model.return_value,
             instructions=None,
             tools=[
                 mock_function_tool(search_web),
@@ -139,7 +139,7 @@ def test_load_openai_agent_missing() -> None:
         with pytest.raises(ImportError):
             AnyAgent.create(
                 AgentFramework.OPENAI,
-                AgentConfig(model_id="mistral/mistral-small-latest"),
+                AgentConfig(model_id="mistral:mistral-small-latest"),
             )
 
 
@@ -154,7 +154,7 @@ def test_run_openai_with_custom_args() -> None:
         patch("any_agent.frameworks.openai.DEFAULT_MODEL_TYPE"),
     ):
         agent = AnyAgent.create(
-            AgentFramework.OPENAI, AgentConfig(model_id="mistral/mistral-small-latest")
+            AgentFramework.OPENAI, AgentConfig(model_id="mistral:mistral-small-latest")
         )
         agent.run("foo", max_turns=30)
         mock_runner.run.assert_called_once_with(
@@ -173,7 +173,7 @@ def test_run_openai_with_inf_max_turns() -> None:
         patch("any_agent.frameworks.openai.DEFAULT_MODEL_TYPE"),
     ):
         agent = AnyAgent.create(
-            AgentFramework.OPENAI, AgentConfig(model_id="mistral/mistral-small-latest")
+            AgentFramework.OPENAI, AgentConfig(model_id="mistral:mistral-small-latest")
         )
         agent.run("foo")
         mock_runner.run.assert_called_once_with(
